@@ -233,84 +233,86 @@ pub const ECTRLC: i32 = 130;
 pub const EUTF8: i32 = 166;
 
 impl fmt::Display for PosixError {
-    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+    #[inline]
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         return write!(f, "{}", self.message);
     }
 }
 
 impl From<std::io::Error> for PosixError {
+    #[inline]
     fn from(error: std::io::Error) -> Self {
         match error.kind() {
-            ErrorKind::NotFound => PosixError {
+            ErrorKind::NotFound => Self {
                 code: ENOENT,
                 message: error.to_string(),
             },
-            ErrorKind::PermissionDenied => PosixError {
+            ErrorKind::PermissionDenied => Self {
                 code: EACCES,
                 message: error.to_string(),
             },
-            ErrorKind::ConnectionRefused => PosixError {
+            ErrorKind::ConnectionRefused => Self {
                 code: ECONNREFUSED,
                 message: error.to_string(),
             },
 
-            ErrorKind::ConnectionReset => PosixError {
+            ErrorKind::ConnectionReset => Self {
                 code: ECONNRESET,
                 message: error.to_string(),
             },
-            ErrorKind::ConnectionAborted => PosixError {
+            ErrorKind::ConnectionAborted => Self {
                 code: ECONNABORTED,
                 message: error.to_string(),
             },
-            ErrorKind::NotConnected => PosixError {
+            ErrorKind::NotConnected => Self {
                 code: ENOTCONN,
                 message: error.to_string(),
             },
-            ErrorKind::AddrInUse => PosixError {
+            ErrorKind::AddrInUse => Self {
                 code: EADDRINUSE,
                 message: error.to_string(),
             },
-            ErrorKind::AddrNotAvailable => PosixError {
+            ErrorKind::AddrNotAvailable => Self {
                 code: EADDRNOTAVAIL,
                 message: error.to_string(),
             },
-            ErrorKind::BrokenPipe => PosixError {
+            ErrorKind::BrokenPipe => Self {
                 code: EPIPE,
                 message: error.to_string(),
             },
-            ErrorKind::AlreadyExists => PosixError {
+            ErrorKind::AlreadyExists => Self {
                 code: EEXIST,
                 message: error.to_string(),
             },
-            ErrorKind::WouldBlock => PosixError {
+            ErrorKind::WouldBlock => Self {
                 code: EWOULDBLOCK,
                 message: error.to_string(),
             },
-            ErrorKind::InvalidInput => PosixError {
+            ErrorKind::InvalidInput => Self {
                 code: EINVAL,
                 message: error.to_string(),
             },
-            ErrorKind::InvalidData => PosixError {
+            ErrorKind::InvalidData => Self {
                 code: EFTYPE,
                 message: error.to_string(),
             },
-            ErrorKind::TimedOut => PosixError {
+            ErrorKind::TimedOut => Self {
                 code: ETIMEDOUT,
                 message: error.to_string(),
             },
-            ErrorKind::WriteZero => PosixError {
+            ErrorKind::WriteZero => Self {
                 code: ENOLINK,
                 message: error.to_string(),
             },
-            ErrorKind::Interrupted => PosixError {
+            ErrorKind::Interrupted => Self {
                 code: EINTR,
                 message: error.to_string(),
             },
-            ErrorKind::UnexpectedEof => PosixError {
+            ErrorKind::UnexpectedEof => Self {
                 code: ESHUTDOWN,
                 message: error.to_string(),
             },
-            _ => PosixError {
+            _ => Self {
                 code: EPERM,
                 message: error.to_string(),
             },
@@ -319,48 +321,60 @@ impl From<std::io::Error> for PosixError {
 }
 
 impl From<std::process::Output> for PosixError {
+    #[inline]
     fn from(output: std::process::Output) -> Self {
-        assert!(!output.status.success());
-        let tmp = String::from_utf8(output.stderr).unwrap();
-        PosixError::new(output.status.code().unwrap(), tmp)
+        let tmp = String::from_utf8_lossy(&output.stderr).to_string();
+        let mut code = output.status.code().unwrap_or(1);
+        if code == 0 {
+            // This should not happen, but who knows.
+            code = 1;
+        }
+        Self::new(code, tmp)
     }
 }
 
 impl PosixError {
     /// Create a new [`PosixError`]
     #[must_use]
-    pub fn new(code: i32, message: String) -> PosixError {
-        PosixError { code, message }
+    #[inline]
+    pub const fn new(code: i32, message: String) -> Self {
+        Self { code, message }
     }
 
     /// Return the posix error code
     #[must_use]
-    pub fn code(&self) -> i32 {
+    #[inline]
+    pub const fn code(&self) -> i32 {
         self.code
     }
 
     /// Return the error message
     #[must_use]
+    #[inline]
     pub fn message(&self) -> String {
         self.message.clone()
     }
 }
 
+/// Create new `PosixError`
 #[must_use]
+#[inline]
 pub fn posix_error(code: i32, msg: &str) -> PosixError {
-    PosixError::new(code, msg.to_string())
+    PosixError::new(code, msg.to_owned())
 }
 
 /// Convert [`std::io::Error`] to a [`PosixError`]
 #[allow(clippy::needless_pass_by_value)]
 #[deprecated(since = "1.1.0", note = "Please use PosixError::from")]
 #[must_use]
+#[inline]
 pub fn to_posix_error(err: std::io::Error) -> PosixError {
     PosixError::from(err)
 }
 
 /// Return a [`PosixError`] from a failed [`std::process::Output`]
 #[must_use]
+#[inline]
 #[deprecated(since = "1.1.0", note = "Please use PosixError::from")]
 pub fn error_from_output(output: std::process::Output) -> PosixError {
     PosixError::from(output)
